summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/first_run_search_engine_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/views/first_run_search_engine_view.h')
-rw-r--r--chrome/browser/views/first_run_search_engine_view.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/chrome/browser/views/first_run_search_engine_view.h b/chrome/browser/views/first_run_search_engine_view.h
index b012e22..774c682 100644
--- a/chrome/browser/views/first_run_search_engine_view.h
+++ b/chrome/browser/views/first_run_search_engine_view.h
@@ -85,9 +85,10 @@ class FirstRunSearchEngineView
public:
// |observer| is the FirstRunView that waits for us to pass back a search
// engine choice; |profile| allows us to get the set of imported search
// engines, and display the KeywordEditorView on demand.
FirstRunSearchEngineView(SearchEngineSelectionObserver* observer,
- Profile* profile);
+ Profile* profile, bool randomize);
virtual ~FirstRunSearchEngineView();
@@ -133,6 +134,9 @@ class FirstRunSearchEngineView
bool text_direction_is_rtl_;
+ // If logos are to be displayed in random order. Used for UX testing.
+ bool randomize_;
+
// UI elements:
// Text above the first horizontal separator
views::Label* title_label_;
@@ -85,9 +85,10 @@ class FirstRunSearchEngineView
// |observer| is the FirstRunView that waits for us to pass back a search
// engine choice; |profile| allows us to get the set of imported search
- // engines, and display the KeywordEditorView on demand.
+ // engines, and display the KeywordEditorView on demand; |randomize|
+ // is true if logos are to be displayed in random order.
FirstRunSearchEngineView(SearchEngineSelectionObserver* observer,